==> nextcloud-15.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/ro.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nu se poate scrie în folderul \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Aceasta se poate repara de obicei prin permiterea accesului de scriere la dosarul de configurare al serverului Web",
    "See %s" : "Vezi %s",
    "Sample configuration detected" : "A fost detectată o configurație exemplu",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S-a detectat copierea configurației exemplu. Acest lucru poate duce la oprirea instanței tale și nu este suportat. Te rugăm să citești documentația înainte de a face modificări în fișierul config.php",
    "%1$s and %2$s" : "%1$s și %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s și %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s și %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s și %5$s",
    "PHP %s or higher is required." : "Versiunea PHP %s sau mai mare este necesară.",
    "PHP with a version lower than %s is required." : "Este necesară o versiune PHP mai mică decât %s",
    "%sbit or higher PHP required." : "Este necesar PHP %sbit sau mai mare.",
    "Following databases are supported: %s" : "Următoarele baze de date sunt suportate: %s",
    "The command line tool %s could not be found" : "Unealta în linie de comandă %s nu a fost găsită",
    "The library %s is not available." : "Biblioteca %s nu este disponibilă.",
    "Following platforms are supported: %s" : "Sunt suportate următoarele platforme: %s",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "today" : "astăzi",
    "tomorrow" : "mâine",
    "yesterday" : "ieri",
    "_%n day ago_::_%n days ago_" : ["Acum o zi","Acum %n zile","Acum %n zile"],
    "last month" : "ultima lună",
    "_%n month ago_::_%n months ago_" : ["%n lună în urmă","%n luni în urmă","%n luni în urmă"],
    "last year" : "ultimul an",
    "_%n year ago_::_%n years ago_" : ["%n an în urmă","%n ani în urmâ","%n ani în urmâ"],
    "in a few seconds" : "în câteva secunde",
    "seconds ago" : "secunde în urmă",
    "File name is a reserved word" : "Numele fișierului este un cuvânt rezervat",
    "File name contains at least one invalid character" : "Numele fișierului conține măcar un caracter invalid",
    "File name is too long" : "Numele fișierului este prea lung",
    "Dot files are not allowed" : "Fișierele care încep cu caracterul punct nu sunt permise",
    "Empty filename is not allowed" : "Nu este permis fișier fără nume",
    "__language_name__" : "Română",
    "Help" : "Ajutor",
    "Apps" : "Aplicații",
    "Settings" : "Setări",
    "Log out" : "Ieșire",
    "Users" : "Utilizatori",
    "Unknown user" : "Utilizator necunoscut",
    "Basic settings" : "Setări de bază",
    "Sharing" : "Partajare",
    "Security" : "Securitate",
    "Additional settings" : "Setări adiționale",
    "Personal info" : "Informații personale",
    "Verifying …" : "Se verifică ...",
    "Verify" : "Verifică",
    "%s enter the database username and name." : "%s introdu numele de utilizator și parola pentru baza de date.",
    "%s enter the database username." : "%s introdu utilizatorul bazei de date.",
    "%s enter the database name." : "%s introduceți numele bazei de date",
    "Oracle connection could not be established" : "Conexiunea Oracle nu a putut fi stabilită",
    "Oracle username and/or password not valid" : "Numele de utilizator sau / și parola Oracle nu sunt valide",
    "PostgreSQL username and/or password not valid" : "Nume utilizator și/sau parolă PostgreSQL greșită",
    "For the best results, please consider using a GNU/Linux server instead." : "Pentru cele mai bune rezultate, ia în calcul folosirea unui server care rulează un sistem de operare GNU/Linux.",
    "Set an admin username." : "Setează un nume de administrator.",
    "Set an admin password." : "Setează o parolă de administrator.",
    "Invalid Federated Cloud ID" : "ID invalid cloud federalizat",
    "Sharing %s failed, because the file does not exist" : "Partajarea %s a eșuat deoarece fișierul nu există",
    "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
    "Sharing %s failed, because you can not share with yourself" : "Partajarea %s a eșuat deoarece nu-l poți partaja cu tine însuți",
    "Not allowed to create a federated share with the same user" : "Nu este permisă crearea unei partajări federalizate cu acelaşi utilizator",
    "Files can’t be shared with delete permissions" : "Fișierele nu pot fi partajate cu permisiuni de ștergere",
    "Expiration date is in the past" : "Data expirării este în trecut",
    "Could not find category \"%s\"" : "Cloud nu a gasit categoria \"%s\"",
    "Sunday" : "Duminică",
    "Monday" : "Luni",
    "Tuesday" : "Marți",
    "Wednesday" : "Miercuri",
    "Thursday" : "Joi",
    "Friday" : "Vineri",
    "Saturday" : "Sâmbătă",
    "Sun." : "Dum.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Joi",
    "Fri." : "Vin.",
    "Sat." : "Sâm.",
    "Su" : "Du",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Jo",
    "Fr" : "Vi",
    "Sa" : "Sâ",
    "January" : "Ianuarie",
    "February" : "Februarie",
    "March" : "Martie",
    "April" : "Aprilie",
    "May" : "Mai",
    "June" : "Iunie",
    "July" : "Iulie",
    "August" : "August",
    "September" : "Septembrie",
    "October" : "Octombrie",
    "November" : "Noiembrie",
    "December" : "Decembrie",
    "Jan." : "Ian.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Iun.",
    "Jul." : "Iul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Noi.",
    "Dec." : "Dec.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Numai următoarele caractere sunt permise în numele utilizatorului: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "Username contains whitespace at the beginning or at the end" : "Utilizatorul contine spațiu liber la început sau la sfârșit",
    "Username must not consist of dots only" : "Numele utilizatorului nu poate conține numai puncte",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "The username is already being used" : "Numele de utilizator este deja folosit",
    "Could not create user" : "Nu s-a putut crea utilizatorul",
    "User disabled" : "Utilizator dezactivat",
    "Application is not enabled" : "Aplicația nu este activată",
    "Authentication error" : "Eroare la autentificare",
    "Token expired. Please reload page." : "Token expirat. Te rugăm să reîncarci pagina.",
    "Cannot write into \"config\" directory" : "Nu se poate scrie în folderul \"config\"",
    "Cannot write into \"apps\" directory" : "Nu se poate scrie în folderul \"apps\"",
    "PHP module %s not installed." : "Modulul PHP %s nu este instalat.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Setarea PHP \"%s\" nu este setată la \"%s\".",
    "PHP modules have been installed, but they are still listed as missing?" : "Modulele PHP au fost instalate, dar apar ca lipsind?",
    "PostgreSQL >= 9 required" : "Este necesară versiunea 9 sau mai mare a PostgreSQL",
    "Please upgrade your database version" : "Actualizați baza de date la o versiune mai nouă",
    "Sharing %s failed, because the user %s does not exist" : "Partajarea %s a eșuat deoarece utilizatorul %s nu există",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Partajarea %s a eșuat deoarece utilizatorul %s nu face parte din niciunul din grupurile din care %s face parte",
    "Sharing %s failed, because this item is already shared with %s" : "Partajarea %s a eșuat deoarece acest element este deja partajat cu %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Partajarea %s a eșuat deoarece acest element este deja partajat cu utilizatorul %s",
    "Sharing %s failed, because the group %s does not exist" : "Partajarea %s a eșuat deoarece grupul %s nu există",
    "Sharing %s failed, because %s is not a member of the group %s" : "Partajarea %s a eșuat deoarce %s nu face parte din grupul %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Partajarea %s a eşuat, nu pot găsi %s, poate serverul nu poate fi contactat.",
    "Share type %s is not valid for %s" : "Tipul partajării %s nu este valid pentru %s",
    "%s shared »%s« with you" : "%s Partajat »%s« cu tine de",
    "%s shared »%s« with you." : "%s a partajat »%s« cu tine.",
    "%s via %s" : "%s via %s"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/ro.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nu se poate scrie în folderul \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Aceasta se poate repara de obicei prin permiterea accesului de scriere la dosarul de configurare al serverului Web",
    "See %s" : "Vezi %s",
    "Sample configuration detected" : "A fost detectată o configurație exemplu",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S-a detectat copierea configurației exemplu. Acest lucru poate duce la oprirea instanței tale și nu este suportat. Te rugăm să citești documentația înainte de a face modificări în fișierul config.php",
    "%1$s and %2$s" : "%1$s și %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s și %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s și %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s și %5$s",
    "PHP %s or higher is required." : "Versiunea PHP %s sau mai mare este necesară.",
    "PHP with a version lower than %s is required." : "Este necesară o versiune PHP mai mică decât %s",
    "%sbit or higher PHP required." : "Este necesar PHP %sbit sau mai mare.",
    "Following databases are supported: %s" : "Următoarele baze de date sunt suportate: %s",
    "The command line tool %s could not be found" : "Unealta în linie de comandă %s nu a fost găsită",
    "The library %s is not available." : "Biblioteca %s nu este disponibilă.",
    "Following platforms are supported: %s" : "Sunt suportate următoarele platforme: %s",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "today" : "astăzi",
    "tomorrow" : "mâine",
    "yesterday" : "ieri",
    "_%n day ago_::_%n days ago_" : ["Acum o zi","Acum %n zile","Acum %n zile"],
    "next month" : "luna viitoare",
    "last month" : "ultima lună",
    "_%n month ago_::_%n months ago_" : ["%n lună în urmă","%n luni în urmă","%n luni în urmă"],
    "next year" : "anul viitor",
    "last year" : "ultimul an",
    "_%n year ago_::_%n years ago_" : ["%n an în urmă","%n ani în urmâ","%n ani în urmâ"],
    "in a few seconds" : "în câteva secunde",
    "seconds ago" : "secunde în urmă",
    "File name is a reserved word" : "Numele fișierului este un cuvânt rezervat",
    "File name contains at least one invalid character" : "Numele fișierului conține măcar un caracter invalid",
    "File name is too long" : "Numele fișierului este prea lung",
    "Dot files are not allowed" : "Fișierele care încep cu caracterul punct nu sunt permise",
    "Empty filename is not allowed" : "Nu este permis fișier fără nume",
    "__language_name__" : "Română",
    "Help" : "Ajutor",
    "Apps" : "Aplicații",
    "Settings" : "Setări",
    "Log out" : "Ieșire",
    "Users" : "Utilizatori",
    "Unknown user" : "Utilizator necunoscut",
    "Basic settings" : "Setări de bază",
    "Sharing" : "Partajare",
    "Security" : "Securitate",
    "Additional settings" : "Setări adiționale",
    "Personal info" : "Informații personale",
    "%s enter the database username and name." : "%s introdu numele de utilizator și parola pentru baza de date.",
    "%s enter the database username." : "%s introdu utilizatorul bazei de date.",
    "%s enter the database name." : "%s introduceți numele bazei de date",
    "Oracle connection could not be established" : "Conexiunea Oracle nu a putut fi stabilită",
    "Oracle username and/or password not valid" : "Numele de utilizator sau / și parola Oracle nu sunt valide",
    "PostgreSQL username and/or password not valid" : "Nume utilizator și/sau parolă PostgreSQL greșită",
    "For the best results, please consider using a GNU/Linux server instead." : "Pentru cele mai bune rezultate, ia în calcul folosirea unui server care rulează un sistem de operare GNU/Linux.",
    "Set an admin username." : "Setează un nume de administrator.",
    "Set an admin password." : "Setează o parolă de administrator.",
    "Invalid Federated Cloud ID" : "ID invalid cloud federalizat",
    "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
    "Files can’t be shared with delete permissions" : "Fișierele nu pot fi partajate cu permisiuni de ștergere",
    "Expiration date is in the past" : "Data expirării este în trecut",
    "Could not find category \"%s\"" : "Cloud nu a gasit categoria \"%s\"",
    "Sunday" : "Duminică",
    "Monday" : "Luni",
    "Tuesday" : "Marți",
    "Wednesday" : "Miercuri",
    "Thursday" : "Joi",
    "Friday" : "Vineri",
    "Saturday" : "Sâmbătă",
    "Sun." : "Dum.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Joi",
    "Fri." : "Vin.",
    "Sat." : "Sâm.",
    "Su" : "Du",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Jo",
    "Fr" : "Vi",
    "Sa" : "Sâ",
    "January" : "Ianuarie",
    "February" : "Februarie",
    "March" : "Martie",
    "April" : "Aprilie",
    "May" : "Mai",
    "June" : "Iunie",
    "July" : "Iulie",
    "August" : "August",
    "September" : "Septembrie",
    "October" : "Octombrie",
    "November" : "Noiembrie",
    "December" : "Decembrie",
    "Jan." : "Ian.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Iun.",
    "Jul." : "Iul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Noi.",
    "Dec." : "Dec.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Numai următoarele caractere sunt permise în numele utilizatorului: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "Username contains whitespace at the beginning or at the end" : "Utilizatorul contine spațiu liber la început sau la sfârșit",
    "Username must not consist of dots only" : "Numele utilizatorului nu poate conține numai puncte",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "The username is already being used" : "Numele de utilizator este deja folosit",
    "Could not create user" : "Nu s-a putut crea utilizatorul",
    "User disabled" : "Utilizator dezactivat",
    "Application is not enabled" : "Aplicația nu este activată",
    "Authentication error" : "Eroare la autentificare",
    "Token expired. Please reload page." : "Token expirat. Te rugăm să reîncarci pagina.",
    "Cannot write into \"config\" directory" : "Nu se poate scrie în folderul \"config\"",
    "Cannot write into \"apps\" directory" : "Nu se poate scrie în folderul \"apps\"",
    "PHP module %s not installed." : "Modulul PHP %s nu este instalat.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Setarea PHP \"%s\" nu este setată la \"%s\".",
    "PHP modules have been installed, but they are still listed as missing?" : "Modulele PHP au fost instalate, dar apar ca lipsind?",
    "Please upgrade your database version" : "Actualizați baza de date la o versiune mai nouă",
    "Verifying …" : "Se verifică ...",
    "Verify" : "Verifică",
    "Sharing %s failed, because the file does not exist" : "Partajarea %s a eșuat deoarece fișierul nu există",
    "Sharing %s failed, because you can not share with yourself" : "Partajarea %s a eșuat deoarece nu-l poți partaja cu tine însuți",
    "Sharing %s failed, because the user %s does not exist" : "Partajarea %s a eșuat deoarece utilizatorul %s nu există",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Partajarea %s a eșuat deoarece utilizatorul %s nu face parte din niciunul din grupurile din care %s face parte",
    "Sharing %s failed, because this item is already shared with %s" : "Partajarea %s a eșuat deoarece acest element este deja partajat cu %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Partajarea %s a eșuat deoarece acest element este deja partajat cu utilizatorul %s",
    "Sharing %s failed, because the group %s does not exist" : "Partajarea %s a eșuat deoarece grupul %s nu există",
    "Sharing %s failed, because %s is not a member of the group %s" : "Partajarea %s a eșuat deoarce %s nu face parte din grupul %s",
    "Not allowed to create a federated share with the same user" : "Nu este permisă crearea unei partajări federalizate cu acelaşi utilizator",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Partajarea %s a eşuat, nu pot găsi %s, poate serverul nu poate fi contactat.",
    "Share type %s is not valid for %s" : "Tipul partajării %s nu este valid pentru %s",
    "%s shared »%s« with you" : "%s Partajat »%s« cu tine de",
    "%s shared »%s« with you." : "%s a partajat »%s« cu tine.",
    "%s via %s" : "%s via %s",
    "PostgreSQL >= 9 required" : "Este necesară versiunea 9 sau mai mare a PostgreSQL"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
